@@ -1,11 +1,10 @@
+"""Utility module to enable all relevancy apis."""
 from typing import Iterable, Generator
-import gc
 import re
+# import gc
 import spacy
 from spacy import Language
-import pandas as pd
-import numpy as np
-
+# import pandas as pd
 
 nlp_lg = spacy.load('en_core_web_lg', exclude=['lemmatizer', 'ner'])
 # nlp_trf = spacy.load('en_core_web_trf', exclude=['lemmatizer', 'ner'])
